#
# spec file for package python3-gr
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


Name:           python3-gr
Version:        0.20.0
Release:        2.4
License:        MIT
Summary:        Python visualization framework
Url:            http://gr-framework.org
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/g/gr/gr-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  ghostscript-devel
BuildRequires:  gtk2-devel
BuildRequires:  jbig2dec-devel
BuildRequires:  libqt4-devel
BuildRequires:  mupdf-devel-static
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glfw3)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
%if 0%{?suse_version} == 1315
BuildRequires:	libjpeg8-devel
%else
BuildRequires:  pkgconfig(libjpeg)
%endif
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libopenjpeg)
BuildRequires:  pkgconfig(libpng16)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libzmq)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  python3-devel
BuildRequires:  python3-nose
BuildRequires:  python3-numpy-devel >= 1.6
BuildRequires:  python3-opengl
BuildRequires:  python3-qt4-devel
BuildRequires:  python3-setuptools
BuildRequires:  qhull-devel
BuildRequires:  texlive-dvipng
BuildRequires:  texlive-latex
BuildRequires:  wxWidgets-devel
Requires:       python3-numpy >= 1.6
Recommends:     ghostscript-devel
Recommends:     python3-jupyter_notebook
Recommends:     python3-opengl
Recommends:     python3-opengl-accelerate
Recommends:     python3-qt4
Recommends:     texlive-dvipng
Recommends:     texlive-latex

%description
GR is a universal framework for cross-platform visualization
applications. It offers developers a compact, portable and consistent
graphics library for their programs. Applications range from publication
quality 2D graphs to the representation of complex 3D scenes.

*GR* is essentially based on an implementation of a Graphical Kernel
System (GKS) and OpenGL. As a self-contained system it can quickly and
easily be integrated into existing applications (i.e. using the
``ctypes`` mechanism in Python or ``ccall`` in Julia).

The *GR* framework can be used in imperative programming systems or
integrated into modern object-oriented systems, in particular those
based on GUI toolkits. *GR* is characterized by its high
interoperability and can be used with modern web technologies. The *GR*
framework is especially suitable for real-time or signal processing
environments.

*GR* was developed by the Scientific IT-Systems group at the Peter
Gruenberg Institute at Forschunsgzentrum Juelich. The main development has
been done by Josef Heinen who currently maintains the software, but
there are other developers who currently make valuable contributions.
Special thanks to Florian Rhiem (*GR3*] and Christian Felder (qtgr,
setup.py).

Beginning with version 0.10.0 *GR* supports inline graphics which shows
up in IPython's Qt Console or interactive computing environments for
*Python* and *Julia*, such as IPython and Jupyter.

For further information please refer to the
GR home page: http://gr-framework.org

This package contains the 2D plotting tools.  Install %{name}-gr3
for 3D plotting.

%package cairo
Summary:        Python visualization framework - cairo driver
Requires:       %{name} = %{version}

%description cairo
GR is a universal framework for cross-platform visualization
applications. It offers developers a compact, portable and consistent
graphics library for their programs. Applications range from publication
quality 2D graphs to the representation of complex 3D scenes.

This package provides the plugin to render %{name} plots using cairo.

%package fig
Summary:        Python visualization framework - fig driver
Requires:       %{name} = %{version}

%description fig
GR is a universal framework for cross-platform visualization
applications. It offers developers a compact, portable and consistent
graphics library for their programs. Applications range from publication
quality 2D graphs to the representation of complex 3D scenes.

This package provides the plugin to render %{name} plots to fig files.

%package ghostscript
Summary:        Python visualization framework - ghostscript driver
Requires:       %{name} = %{version}

%description ghostscript
GR is a universal framework for cross-platform visualization
applications. It offers developers a compact, portable and consistent
graphics library for their programs. Applications range from publication
quality 2D graphs to the representation of complex 3D scenes.

This package provides the plugin to render %{name} plots using ghostscript.

%package gtk2
Summary:        Python visualization framework - gtk2 driver
Requires:       %{name} = %{version}

%description gtk2
GR is a universal framework for cross-platform visualization
applications. It offers developers a compact, portable and consistent
graphics library for their programs. Applications range from publication
quality 2D graphs to the representation of complex 3D scenes.

This package provides the plugin to render %{name} plots using gtk2.

%package html
Summary:        Python visualization framework - html driver
Requires:       %{name} = %{version}

%description html
GR is a universal framework for cross-platform visualization
applications. It offers developers a compact, portable and consistent
graphics library for their programs. Applications range from publication
quality 2D graphs to the representation of complex 3D scenes.

This package provides the plugin to render %{name} plots as web pages.

%package pgf
Summary:        Python visualization framework - pgf driver
Requires:       %{name} = %{version}

%description pgf
GR is a universal framework for cross-platform visualization
applications. It offers developers a compact, portable and consistent
graphics library for their programs. Applications range from publication
quality 2D graphs to the representation of complex 3D scenes.

This package provides the plugin to render %{name} plots to pgf files.

%package qt4
Summary:        Python visualization framework - qt4 driver
Requires:       %{name} = %{version}

%description qt4
GR is a universal framework for cross-platform visualization
applications. It offers developers a compact, portable and consistent
graphics library for their programs. Applications range from publication
quality 2D graphs to the representation of complex 3D scenes.

This package provides the plugin to render %{name} plots using qt4.

%package svg
Summary:        Python visualization framework - svg driver
Requires:       %{name} = %{version}

%description svg
GR is a universal framework for cross-platform visualization
applications. It offers developers a compact, portable and consistent
graphics library for their programs. Applications range from publication
quality 2D graphs to the representation of complex 3D scenes.

This package provides the plugin to render %{name} plots to svg files.

%package wmf
Summary:        Python visualization framework - wmf driver
Requires:       %{name} = %{version}

%description wmf
GR is a universal framework for cross-platform visualization
applications. It offers developers a compact, portable and consistent
graphics library for their programs. Applications range from publication
quality 2D graphs to the representation of complex 3D scenes.

This package provides the plugin to render %{name} plots to wmf files.

%package wx
Summary:        Python visualization framework - wx driver
Requires:       %{name} = %{version}

%description wx
GR is a universal framework for cross-platform visualization
applications. It offers developers a compact, portable and consistent
graphics library for their programs. Applications range from publication
quality 2D graphs to the representation of complex 3D scenes.

This package provides the plugin to render %{name} plots using wx.

%package matplotlib
Summary:        Python visualization framework - backend for matplotlib
Requires:       %{name} = %{version}
Requires:       python3-matplotlib

%description matplotlib
Allow %{name} to be used as a backend for Matplotlib.  Its
significantly improves the performance of existing
Matplotlib or PyPlot applications written in Python or Julia,
respectively.

%package gr3
Summary:        Python visualization framework - 3D Plotting
Requires:       %{name} = %{version}

%description gr3
GR is a universal framework for cross-platform visualization
applications. It offers developers a compact, portable and consistent
graphics library for their programs. Applications range from publication
quality 2D graphs to the representation of complex 3D scenes.

This package provides OpenGL-based 3D plotting for %{name}.

%package qtgr
Summary:        Python visualization framework - Qt4 widgets
Requires:       %{name} = %{version}
Requires:       python3-qt4

%description qtgr
Easily integrate %{name} into GUI toolkits like Qt.
It provides powerful widgets for 2D plotting and
methods for embedding graphics into user interfaces
based on PySide or PyQt.

%prep
%setup -q -n gr-%{version}

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
python3 setup.py check_ext
python3 setup.py build_ext
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
python3 setup.py test

%files
%defattr(-,root,root,-)
%doc LICENSE.md README.md README.rst
%dir %{python3_sitearch}/gr/
%{python3_sitearch}/gr/__init__.py
%{python3_sitearch}/gr/_version.py
%{python3_sitearch}/gr/__pycache__/
%{python3_sitearch}/gr/libGR.so
%{python3_sitearch}/gr/libGKS.so
%{python3_sitearch}/gr/fonts/
%{python3_sitearch}/gr/pygr/
%{python3_sitearch}/gr-%{version}-py*.egg-info
%exclude %{python3_sitearch}/gr/matplotlib/

%files gr3
%defattr(-,root,root,-)
%doc LICENSE.md README.md README.rst
%{python3_sitearch}/gr3/

%files cairo
%defattr(-,root,root,-)
%{python3_sitearch}/gr/cairoplugin.so

%files fig
%defattr(-,root,root,-)
%{python3_sitearch}/gr/figplugin.so

%files ghostscript
%defattr(-,root,root,-)
%{python3_sitearch}/gr/gsplugin.so

%files gtk2
%defattr(-,root,root,-)
%{python3_sitearch}/gr/gtkplugin.so

%files html
%defattr(-,root,root,-)
%{python3_sitearch}/gr/htmplugin.so

%files pgf
%defattr(-,root,root,-)
%{python3_sitearch}/gr/pgfplugin.so

%files qt4
%defattr(-,root,root,-)
%{python3_sitearch}/gr/qtplugin.so

%files svg
%defattr(-,root,root,-)
%{python3_sitearch}/gr/svgplugin.so

%files wmf
%defattr(-,root,root,-)
%{python3_sitearch}/gr/wmfplugin.so

%files wx
%defattr(-,root,root,-)
%{python3_sitearch}/gr/wxplugin.so

%files matplotlib
%defattr(-,root,root,-)
%{python3_sitearch}/gr/matplotlib/

%files qtgr
%defattr(-,root,root,-)
%{python3_sitearch}/qtgr/

%changelog
* Tue Jun  6 2017 gutaper@gmail.com
- Fix .spec file for openSUSE Leap 42.x
* Mon Apr 18 2016 toddrme2178@gmail.com
- Initial version
